netapp_ontap.models.fpolicy_event_filters API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.fpolicy_event_filters`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class FpolicyEventFiltersSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the FpolicyEventFilters object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `close_with_modification GET POST PATCH`

    Filter the client request for close with modification.

  `close_with_read GET POST PATCH`

    Filter the client request for close with read.

  `close_without_modification GET POST PATCH`

    Filter the client request for close without modification.

  `exclude_directory GET POST PATCH`

    Filter the client requests for directory operations. When this filter is specified directory operations are not monitored.

  `first_read GET POST PATCH`

    Filter the client requests for the first-read.

  `first_write GET POST PATCH`

    Filter the client requests for the first-write.

  `monitor_ads GET POST PATCH`

    Filter the client request for alternate data stream.

  `offline_bit GET POST PATCH`

    Filter the client request for offline bit set. FPolicy server receives notification only when offline files are accessed.

  `open_with_delete_intent GET POST PATCH`

    Filter the client request for open with delete intent.

  `open_with_write_intent GET POST PATCH`

    Filter the client request for open with write intent.

  `setattr_with_access_time_change GET POST PATCH`

    Filter the client setattr requests for changing the access time of a file or directory.

  `setattr_with_allocation_size_change GET POST PATCH`

    Filter the client setattr requests for changing the allocation size of a file.

  `setattr_with_creation_time_change GET POST PATCH`

    Filter the client setattr requests for changing the creation time of a file or directory.

  `setattr_with_dacl_change GET POST PATCH`

    Filter the client setattr requests for changing dacl on a file or directory.

  `setattr_with_group_change GET POST PATCH`

    Filter the client setattr requests for changing group of a file or directory.

  `setattr_with_mode_change GET POST PATCH`

    Filter the client setattr requests for changing the mode bits on a file or directory.

  `setattr_with_modify_time_change GET POST PATCH`

    Filter the client setattr requests for changing the modification time of a file or directory.

  `setattr_with_owner_change GET POST PATCH`

    Filter the client setattr requests for changing owner of a file or directory.

  `setattr_with_sacl_change GET POST PATCH`

    Filter the client setattr requests for changing sacl on a file or directory.

  `setattr_with_size_change GET POST PATCH`

    Filter the client setattr requests for changing the size of a file.

  `write_with_size_change GET POST PATCH`

    Filter the client request for write with size change.